<h1>Download Reels</h1>
<h2>Steps:-</h2>
<p>Clone it using 'git clone https://github.com/tanaymishra/reels/tree/master'</p>
<p>*Clone it in the Same working Directory</p>
<p>Then come to your code(where you want to use this)</p>
<p>And type :- "from reels-downloader.reels import download"</p>
<p>And call this function Using :- "download('link','video.mp4')</p>
<p>And that's it video will be downloaded..</p>